==> claromentis-framework-9.6.6-26891208.zip: web/intranet/core/classes/Config/Events/ConfigUpdateEvent.php <==
<?php
namespace Claromentis\Core\Config\Events;

$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] = (@$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] ?: array()) + array("_d706c160e45bf74" . "34fff82a5976f0e1" . "9" => base64_decode("YXJyYXlfa2V5" . "cw=="));
use Claromentis\Core\Config\Config;
use Claromentis\Core\Config\LayeredConfig;
use Claromentis\Core\Config\WritableConfig;
use Claromentis\Core\Event\Event;




class ConfigUpdateEvent extends Event
{
    
    
    
    
    
    
    protected Config $config;
    
    
    
    
    
    
    protected array $previousValues;
    
    
    
    
    
    
    protected array $currentValues;
    
    
    
    
    
    
    public function __construct(Config $config, array $_8c3ab09b3b48146f1b2f7a9475b96f86 = [], array $_e4755d2d4c4cef067aac894900cee333 = [])
    {
        $this->setConfig($config);
        $this->setCurrentValues($_e4755d2d4c4cef067aac894900cee333);
        $this->setPreviousValues($_8c3ab09b3b48146f1b2f7a9475b96f86);
    }
    
    
    
    
    
    
    
    
    public function getConfig() : Config
    {
        return $this->config;
    }
    
    
    
    
    
    
    public function getKeys() : array
    {
        return $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_d706c160e45bf7434fff82a597" . "6f0e19"]($this->currentValues);
    }
    
    
    
    
    
    
    public function getCurrentValues() : array
    {
        return $this->currentValues;
    }
    
    
    
    
    
    
    public function getPreviousValues() : array
    {
        return $this->previousValues;
    }
    
    
    
    
    
    
    private function setConfig(Config $config) : void
    {
        $this->config = $config;
    }
    
    
    
    
    
    
    private function setPreviousValues(array $values) : void
    {
        $this->previousValues = $values;
    }
    
    
    
    
    
    
    private function setCurrentValues(array $values) : void
    {
        $this->currentValues = $values;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/core/classes/Config/Events/ConfigUpdateEvent.php <==
<?php
namespace Claromentis\Core\Config\Events;

$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"] ?: array()) + array("_d706c160e45bf7434fff82a597" . "6f0e19" => base64_decode("YXJyYX" . "lfa2V5" . "cw=="));
use Claromentis\Core\Config\Config;
use Claromentis\Core\Config\LayeredConfig;
use Claromentis\Core\Config\WritableConfig;
use Claromentis\Core\Event\Event;




class ConfigUpdateEvent extends Event
{
    
    
    
    
    
    
    protected Config $config;
    
    
    
    
    
    
    protected array $previousValues;
    
    
    
    
    
    
    protected array $currentValues;
    
    
    
    
    
    
    public function __construct(Config $config, array $_8c3ab09b3b48146f1b2f7a9475b96f86 = [], array $_e4755d2d4c4cef067aac894900cee333 = [])
    {
        $this->setConfig($config);
        $this->setCurrentValues($_e4755d2d4c4cef067aac894900cee333);
        $this->setPreviousValues($_8c3ab09b3b48146f1b2f7a9475b96f86);
    }
    
    
    
    
    
    
    
    
    public function getConfig() : Config
    {
        return $this->config;
    }
    
    
    
    
    
    
    public function getKeys() : array
    {
        return $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_d706c160e45b" . "f7434fff82a59" . "76f0e19"]($this->currentValues);
    }
    
    
    
    
    
    
    public function getCurrentValues() : array
    {
        return $this->currentValues;
    }
    
    
    
    
    
    
    public function getPreviousValues() : array
    {
        return $this->previousValues;
    }
    
    
    
    
    
    
    private function setConfig(Config $config) : void
    {
        $this->config = $config;
    }
    
    
    
    
    
    
    private function setPreviousValues(array $values) : void
    {
        $this->previousValues = $values;
    }
    
    
    
    
    
    
    private function setCurrentValues(array $values) : void
    {
        $this->currentValues = $values;
    }
}
